
import { Link, useLocation } from 'react-router-dom';
import { Facebook, Instagram, Linkedin, Youtube } from 'lucide-react';
import { ClientReviews } from '@/components/ui/client-reviews';
import SocialLinks from './footer/SocialLinks';
import QuickLinksSection from './footer/QuickLinksSection';
import GetStartedSection from './footer/GetStartedSection';
import ContactInfo from './footer/ContactInfo';

const Footer = () => {
  const location = useLocation();

  const handleParentsClick = () => {
    // Always scroll to top when clicking For Parents link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const handleTeachersClick = () => {
    // Always scroll to top when clicking For Teachers link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const handleFaqClick = () => {
    // Always scroll to top when clicking FAQ link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const handleVideosClick = () => {
    // Always scroll to top when clicking Video Resources link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const handleSitemapClick = () => {
    // Always scroll to top when clicking Site Map link
    setTimeout(() => {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }, 100);
  };

  const socialLinks = [
    {
      name: 'TikTok',
      url: 'https://www.tiktok.com/@theiepcoach',
      customIcon: '/lovable-uploads/9268acbb-da9a-4f55-b3cf-8773ac7f70db.png',
      label: 'Follow us on TikTok'
    },
    {
      name: 'Facebook',
      url: 'https://www.facebook.com/theiepcoach',
      icon: Facebook,
      label: 'Follow us on Facebook'
    },
    {
      name: 'YouTube',
      url: 'https://www.youtube.com/@TheIEPCoach1',
      icon: Youtube,
      label: 'Subscribe to our YouTube channel'
    },
    {
      name: 'Instagram',
      url: 'https://www.instagram.com/the.iep.coach/',
      icon: Instagram,
      label: 'Follow us on Instagram'
    },
    {
      name: 'LinkedIn',
      url: 'https://www.linkedin.com/in/theiepcoach/',
      icon: Linkedin,
      label: 'Connect with us on LinkedIn'
    },
    {
      name: 'X (Twitter)',
      url: 'https://x.com/TheIEPCoach1',
      customIcon: '/lovable-uploads/d2e0dfa7-fb71-4ee5-a737-1271a6d81395.png',
      label: 'Follow us on X'
    }
  ];

  const demoReviews = [
    {
      rating: 5,
      reviewer: "Sarah M.",
      roleReviewer: "Parent",
      review:
        "The IEP Coach helped us navigate our first IEP meeting with confidence. The expertise made all the difference in securing the services our child needed.",
      date: "2025",
    },
    {
      rating: 5,
      reviewer: "Jennifer L.",
      roleReviewer: "Parent",
      review:
        "Professional, knowledgeable, and truly caring. Everything was fully explained in terms we could understand.",
      date: "2025",
    },
    {
      rating: 5,
      reviewer: "Michael R.",
      roleReviewer: "Parent",
      review:
        "Outstanding support throughout the entire IEP process. Worth every penny to have someone who knows the system fighting for your child.",
      date: "2025",
    },
  ];

  return (
    <footer className="bg-gradient-to-br from-primary via-blue-900 to-slate-900 text-white relative overflow-hidden">
      <div className="absolute inset-0 opacity-30" style={{
        backgroundImage: `url("data:image/svg+xml,%3Csvg width='60' height='60' viewBox='0 0 60 60' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='none' fill-rule='evenodd'%3E%3Cg fill='%23ffffff' fill-opacity='0.03'%3E%3Ccircle cx='30' cy='30' r='1'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`
      }}></div>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-16 relative">
        <div className="grid md:grid-cols-4 gap-12">
          <div className="col-span-2">
            <p className="text-blue-100 mb-8 text-lg leading-relaxed col-span-2">
              The IEP Coach™ provides IEP advocacy and special education support for families across Texas and nationwide. We help you understand your rights and fight for the services your child deserves.
            </p>
            
            <div className="grid md:grid-cols-2 gap-8">
              <div>
                <QuickLinksSection 
                  handleParentsClick={handleParentsClick}
                  handleTeachersClick={handleTeachersClick}
                  handleFaqClick={handleFaqClick}
                  handleVideosClick={handleVideosClick}
                />
                
                <ContactInfo />
              </div>

              <div>
                <GetStartedSection handleSitemapClick={handleSitemapClick} />

                <SocialLinks socialLinks={socialLinks} />
              </div>
            </div>
          </div>

          <div className="col-span-2">
            <ClientReviews reviews={demoReviews} className="bg-white/10 backdrop-blur-md border-white/20 text-white" />
          </div>
        </div>

        <div className="border-t border-white/20 mt-12 pt-8 text-center">
          <p className="text-blue-100 text-lg">
            © 2025 The IEP Coach, LLC. All rights reserved. | <span className="bg-gradient-to-r from-accent to-yellow-400 bg-clip-text text-transparent font-semibold">What Schools Don't Share But Parents Must Know</span>
          </p>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
